# -*- coding: utf-8 -*-
from sklearn.ensemble import AdaBoostClassifier
import pandas as pd
import sys
import numpy as np
from sklearn.metrics import precision_score, recall_score, accuracy_score, f1_score, roc_auc_score
import json
from sklearn.tree import DecisionTreeClassifier


class Result:
    precision = 0
    recall = 0
    accuracy = 0
    rocX = []
    rocY = []
    featureImportances = []
params = {}
params['learning_rate'] = 1.
params['n_estimators'] = 50
params['base_estimator'] = 'DecisionTreeClassifier'
params['algorithm'] = 'SAMME'
params['random_state'] = None
params['train'] = '/Users/zangmenglei/train.csv'
params['test'] = '/Users/zangmenglei/test.csv'
argvs = sys.argv
try:
    for i in range(len(argvs)):
        if i < 1:
            continue
        if argvs[i].split('=')[1] == 'None':
            params[argvs[i].split('=')[0]] = None
        else:
            Type = type(params[argvs[i].split('=')[0]])
            params[argvs[i].split('=')[0]] = Type(argvs[i].split('=')[1])
            
    train = np.array(pd.read_csv(params['train']))
    train_y = train[:, -1]
    train_x = train[:, :-1]

    test = np.array(pd.read_csv(params['test']))
    test_y = test[:, -1]
    test_x = test[:, :-1]
    
    lf=DecisionTreeClassifier(criterion='gini',max_depth=None).fit(train_x, train_y)
    
    clf = AdaBoostClassifier(base_estimator=lf,
                             learning_rate=params['learning_rate'],
                             algorithm=params['algorithm'],
                             n_estimators=params['n_estimators'],
                             random_state=params['random_state']).fit(train_x, train_y)
    
    predict = clf.predict(test_x)
    precision = precision_score(test_y, predict)
    recall = recall_score(test_y, predict)
    accuracy = accuracy_score(test_y, predict)
    res = {}
    res['precision'] = precision
    res['recall'] = recall
    res['accuracy'] = accuracy
    res['fMeasure'] = f1_score(test_y, predict)
    res['rocArea'] = roc_auc_score(test_y, predict)
    res['featureImportances'] = clf.feature_importances_.tolist()
    print(json.dumps(res))
except Exception as e:
    print(e)
